OC.L10N.register(
    "files_external",
    {
    "External storage" : "Kanpoko biltegiratzea",
    "Personal" : "Pertsonala",
    "System" : "Sistema",
    "Grant access" : "Baimendu sarrera",
    "Error configuring OAuth1" : "Errorea OAuth1 konfiguratzean",
    "Please provide a valid app key and secret." : "Eman baliozko aplikazio-gakoa eta sekretua.",
    "Error configuring OAuth2" : "Errorea OAuth2 konfiguratzean",
    "Generate keys" : "Sortu gakoak",
    "Error generating key pair" : "Errorea gako bikotea sortzean",
    "All users. Type to select user or group." : "Erabiltzaile guztiak. Idatzi erabiltzaile edo taldea hautatzeko.",
    "(Group)" : "(Taldea)",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD kodeketarekin bateragarritasuna (mantsoa)",
    "Enable encryption" : "Gaitu zifratzea",
    "Enable previews" : "Gaitu aurrebistak",
    "Enable sharing" : "Gaitu partekatzea",
    "Check for changes" : "Begiratu aldaketarik dagoen",
    "Never" : "Inoiz ez",
    "Once every direct access" : "Sarbide zuzen bakoitzean",
    "Read only" : "Irakurtzeko soilik",
    "Delete" : "Ezabatu",
    "Admin defined" : "Administratzaileak definitua",
    "Are you sure you want to delete this external storage?" : "Ziur zaude kanpoko biltegiratze hau ezabatu nahi duzula?",
    "Delete storage?" : "Biltegiratzea ezabatu?",
    "Saved" : "Gordeta",
    "Saving …" : "Gordetzen …",
    "Save" : "Gorde",
    "Empty response from the server" : "Erantzun hutsa zerbitzaritik",
    "Couldn't access. Please log out and in again to activate this mount point" : "Ezin izan da atzitu. Amaitu saioa eta hasi berriz muntatze-puntu hau aktibatzeko",
    "Couldn't get the information from the remote server: {code} {type}" : "Ezin izan da urruneko zerbitzaritik informaziorik eskuratu:  {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Ezin izan da kanpoko muntatze-puntuen zerrenda eskuratu: {type}",
    "There was an error with message: " : "Errore bat gertatu da mezu honekin:",
    "External mount error" : "Kanpoko muntatzearen errorea",
    "external-storage" : "kanpo-biltegiratzea",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Ezin izan da Windows sareko gailuen muntatze-puntuen zerrenda eskuratu: Erantzun hutsa zerbitzaritik",
    "Please enter the credentials for the {mount} mount" : "Sartu {mount} muntatzearen kredentzialak",
    "Username" : "Erabiltzaile-izena",
    "Password" : "Pasahitza",
    "Credentials saved" : "Kredentzialak gordeta",
    "Credentials saving failed" : "Kredentzialak gordetzeak huts egin du",
    "Credentials required" : "Kredentzialak behar dira",
    "Storage with ID \"%d\" not found" : "Ez da aurkitu \"%d\" IDa duen biltegiratzea",
    "Invalid backend or authentication mechanism class" : "Atzeko alde edo autentifikazio mekanismo klase baliogabea",
    "Invalid mount point" : "Muntatze-puntu baliogabea",
    "Objectstore forbidden" : "Objectstore debekatuta",
    "Invalid storage backend \"%s\"" : "Biltegiratzearen atzeko alde baliogabea: \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ez da onartzen \"%s\" atzeko aldea erabiltzea",
    "Not permitted to use authentication mechanism \"%s\"" : "Ez da onartzen \"%s\" autentifikazio mekanismoa erabiltzea",
    "Unsatisfied backend parameters" : "Atzeko aldearen parametroak ez dira asebete",
    "Unsatisfied authentication mechanism parameters" : "Autentifikazio mekanismoaren parametroak ez dira asebete",
    "Insufficient data: %s" : "Behar baino datu gutxiago: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Erabiltzaileek ezin dute editatu \"%d\" IDa duen biltegiratzea",
    "Access key" : "Sarbide-gakoa",
    "Secret key" : "Gako sekretua",
    "Builtin" : "Integratua",
    "None" : "Bat ere ez",
    "OAuth1" : "OAuth1",
    "App key" : "Aplikazio-gakoa",
    "App secret" : "Aplikazio-sekretua",
    "OAuth2" : "OAuth2",
    "Client ID" : "Bezero ID",
    "Client secret" : "Bezeroaren sekretua",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Maizterraren izena",
    "Identity endpoint URL" : "Identitate amaiera-puntuaren URLa",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domeinua",
    "Rackspace" : "Rackspace",
    "API key" : "APIaren gakoa",
    "Global credentials" : "Kredentzial globalak",
    "Log-in credentials, save in database" : "Saio hasteko kredentzialak, gorde datu-basean",
    "Username and password" : "Erabiltzaile-izena eta pasahitza",
    "Log-in credentials, save in session" : "Saioa hasteko kredentzialak, gorde saioan",
    "Global credentials, user entered" : "Kredentzial globalak, erabiltzaileak sartuak",
    "User entered, store in database" : "Erabiltzaileak sartuak, gorde datu-basean",
    "RSA public key" : "RSA gako publikoa",
    "Public key" : "Gako publikoa",
    "RSA private key" : "RSA gako pribatua",
    "Private key" : "Gako pribatua",
    "Kerberos ticket" : "Kerberos tiketa",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Ontzia",
    "Hostname" : "Ostalari-izena",
    "Port" : "Ataka",
    "Region" : "Eskualdea",
    "Enable SSL" : "Gaitu SSL",
    "Enable Path Style" : "Gaitu bide estiloa",
    "Legacy (v2) authentication" : "Autentifikazio zaharkitua (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Urruneko azpikarpeta",
    "Secure https://" : "https:// segurua",
    "FTP" : "FTP",
    "Host" : "Ostalaria",
    "Secure ftps://" : "ftps:// segurua",
    "Local" : "Lokala",
    "Location" : "Kokapena",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Erroa",
    "SFTP with secret key login" : "SFTP gako sekretu bidezko saio hasierarekin",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Partekatu",
    "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
    "Verify ACL access when listing files" : "Egiaztatu ACL baimena fitxategiak zerrendatzerakoan",
    "Check the ACL's of each file or folder inside a directory to filter out items where the user has no read permissions, comes with a performance penalty" : "Egiaztatu direktorio bateko fitxategi edo karpeta bakoitzaren ACLak erabiltzaileak irakurtzeko baimenik ez duten elementuak iragazteko errendimendu penalizazioarekin.",
    "Timeout" : "Denbora-muga",
    "SMB/CIFS using OC login" : "SMB/CIFS OC saio hasiera erabilita",
    "Username as share" : "Erabiltzaile-izena partekatze bezala",
    "OpenStack Object Storage" : "OpenStack objektu biltegiratzea",
    "Service name" : "Zerbitzuaren izena",
    "Request timeout (seconds)" : "Eskaeraren denbora-muga (segundoak)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPren cURL euskarria ez dago gaituta edo instalatuta. Ezin da %s muntatu. Eskatu administratzaileari instalatzeko.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPren FTP euskarria ez dago gaituta edo instalatuta. Ezin da %s muntatu. Eskatu administratzaileari instalatzeko.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" ez dago instalatuta. Ezin da %2$s muntatu. Eskatu administratzaileari instalatzeko.",
    "External storage support" : "Kanpoko biltegiratzearen euskarria",
    "Adds basic external storage support" : "Gehitu kanpoko biltegiratzearen oinarrizko euskarria",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administrators can choose which types of storage to enable and can mount these storage locations for a user, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows users to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the advanced user with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Aplikazio honek aukera ematen die administratzaileei kanpoko biltegiratze hornitzaileetara konexioak konfiguratzeko, hala nola, FTP zerbitzariak, S3 edo SWIFT objektuen biltegiak, beste Nextcloud zerbitzariak, WebDAV zerbitzariak eta gehiago. Administratzaileak aukeratu dezake ze biltegiratze mota gaitu nahi dituen eta biltegiratze kokaleku horiek erabiltzaile batentzat, talde batentzat edo sistema osorako muntatu ditzake. Erabiltzaileek beren erroko Nextcloud direktorioan karpeta berri bat agertu dela ikusiko dute; bertara sarbidea izango dute eta Nextcloud-eko beste edozein karpeta bezala erabil dezakete. Kanpoko biltegiratzeak kanpoko kokaleku horietan gordetako fitxategiak partekatzeko aukera ematen die erabiltzaileei. Kasu horietan, hartzaileak kanpoko biltegiratzeko fitxategira sarbidea eskatzen duenean fitxategiaren jabearen kredentzialak erabiltzen dira, modu horretan hartzaileak partekatutako fitxategia atzitu dezakeela ziurtatuz.\n\nKanpoko biltegiratzea GUI edo komando lerro bidez konfiguratu daiteke. Bigarren aukerak malgutasun handiagoa eskaintzen dio erabiltzaile aurreratuari, kanpoko biltegiratzeen muntatze multzoka konfiguratzeko eta muntatze lehentasunak ezartzeko. Eskuragarri dago informazio gehiago kanpoko biltegiratzeen GUIaren eta kanpoko biltegiratzearen konfigurazio fitxategiaren dokumentazioetan.",
    "No external storage configured or you don't have the permission to configure them" : "Ez dago kanpoko biltegiratzerik konfiguratuta edo ez daukazu baimenik haiek konfiguratzeko",
    "Name" : "Izena",
    "Storage type" : "Biltegiratze mota",
    "Scope" : "Esparrua",
    "Open documentation" : "Ireki dokumentazioa",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "Kanpoko biltegiratzeak aukera ematen dizu kanpoko biltegiratze zerbitzuak eta gailuak erabiltzeko Nextlcloudeko bigarren mailako biltegiratze gailu bezala. Gainera, aukera eman diezaiekezu erabiltzaileei beren kanpoko biltegiratze zerbitzuak muntatzeko.",
    "Folder name" : "Karpetaren izena",
    "Authentication" : "Autentifikazioa",
    "Configuration" : "Konfigurazioa",
    "Available for" : "Hauentzat eskuragarri",
    "Click to recheck the configuration" : "Egin klik konfigurazioa berriro egiaztatzeko",
    "Add storage" : "Gehitu biltegiratzea",
    "Advanced settings" : "Ezarpen aurreratuak",
    "Allow users to mount external storage" : "Baimendu erabiltzaileek kanpoko biltegiratze zerbitzuak muntatzea",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Kredentzial globalak erabil daitezke kredentzial berdinak dituzten kanpoko hainbat biltegiratzerekin autentifikatzeko.",
    "External storages" : "Kanpoko biltegiratzeak",
    "(group)" : "(taldea)",
    "SMB / CIFS" : "SMB / CIFS",
    "SMB / CIFS using OC login" : "SMB / CIFS OC saioa hasiera erabiliz"
},
"nplurals=2; plural=(n != 1);");
