<?php 
$OC_Version = array(21,0,8,3);
$OC_VersionString = '21.0.8';
$OC_Edition = '';
$OC_Channel = 'stable';
$OC_VersionCanBeUpgradedFrom = array (
  'nextcloud' => 
  array (
    '20.0' => true,
    '21.0' => true,
  ),
  'owncloud' => 
  array (
    '10.5' => true,
  ),
);
$OC_Build = '2022-01-27T20:14:05+00:00 2721bbb5da8a9abb9a8ee610181315ad9b6b8ba8';
$vendor = 'nextcloud';
