OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotod",
    "Your memories under your control" : "Sinu mälestused sinu kontrolli all",
    "Your photos" : "Sinu fotod",
    "Favorites" : "Lemmikud",
    "Shared with you" : "Sinuga jagatud",
    "Tagged photos" : "Sildistatud fotod",
    "Locations" : "Asukohad",
    "Settings" : "Seaded",
    "Open the full size \"{name}\" image" : "Ava \"{name}\" täissuuruses",
    "Open the \"{name}\" sub-directory" : "Ava alamkataloog \"{name}\"",
    "Share this folder" : "Jaga seda kausta",
    "Back to {folder}" : "Tagasi kausta {folder}",
    "An error occurred" : "Tekkis tõrge",
    "No photos in here" : "Siin ei ole fotosid",
    "No tags yet" : "Silte veel pole",
    "Photos with tags will show up here" : "Sildistatud fotod on siin näha",
    "This folder does not exists" : "Seda kausta pole olemas"
},
"nplurals=2; plural=(n != 1);");
