<?php
/**
 * This file has been @generated by a phing task from CLDR version 993632df2f5d6a2d33cbbf40d922474c2482eaca.
 * See [README.md](README.md#generating-data) for more information.
 *
 * @internal Please do not require this file directly.
 * It may change location/format between versions
 *
 * Do not modify this file directly!
 */

return array (
  'AC' => 'جزیرہ اسینشن',
  'AX' => 'جزائر آلینڈ',
  'CC' => 'جزائر (کیلنگ) کوکوس',
  'CK' => 'جزائر کک',
  'DG' => 'ڈیگو گارشیا',
  'FK' => 'جزائر فاکلینڈ',
  'FO' => 'جزائر فیرو',
  'GF' => 'فرانسیسی گیانا',
  'IC' => 'جزائر کناری',
  'IO' => 'برطانوی بحرہند خطہ',
  'MH' => 'جزائر مارشل',
  'MP' => 'جزائر شمالی ماریانا',
  'NF' => 'جزیرہ نارفوک',
  'PN' => 'جزائر پٹکیرن',
  'SB' => 'جزائر سلیمان',
  'TA' => 'ترسٹان دا کونیا',
  'TC' => 'جزائر کیکس و ترکیہ',
  'UM' => 'امریکی بیرونی جزائر',
  'VG' => 'برطانوی جزائر ورجن',
  'VI' => 'امریکی جزائر ورجن',
);
