<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  90212 => 'Istanbul (Avrupa)',
  90222 => 'Eskisehir',
  90232 => 'İzmir',
  90252 => 'Muğla',
  90256 => 'Aydın',
  90262 => 'Kocaeli (İzmit)',
  90264 => 'Sakarya (Adapazarı)',
  90266 => 'Balıkesir',
  90274 => 'Kütahya',
  90276 => 'Uşak',
  90282 => 'Tekirdağ',
  90286 => 'Çanakkale',
  90288 => 'Kırklareli',
  90318 => 'Kırıkkale',
  90324 => 'Mersin',
  90344 => 'Kahramanmaraş',
  90364 => 'Çorum',
  90370 => 'Karabük',
  90372 => 'Zonguldak',
  90376 => 'Çankırı',
  90378 => 'Bartın',
  90380 => 'Düzce',
  90384 => 'Nevşehir',
  90386 => 'Kırşehir',
  90388 => 'Niğde',
  9039 => 'Kuzey Kıbrıs',
  90412 => 'Diyarbakır',
  90414 => 'Şanlıurfa',
  90416 => 'Adıyaman',
  90424 => 'Elazığ',
  90426 => 'Bingöl',
  90428 => 'Tunceli',
  90436 => 'Muş',
  90456 => 'Gümüşhane',
  90472 => 'Ağrı',
  90476 => 'Iğdır',
  90484 => 'Siirt',
  90486 => 'Şırnak',
);
